@@ -1,6 +1,7 @@
 import logging
 import os
 from collections import OrderedDict
+from pathlib import Path
 
 from django.apps import apps
 from django.conf import settings
@@ -9,8 +10,12 @@ from django.utils.translation import gettext_lazy as _
 from django.views.generic import TemplateView
 
 import requests
+import yaml
+from drf_spectacular.plumbing import get_relative_url
+from drf_spectacular.views import SpectacularRedocView, SpectacularYAMLAPIView
 from rest_framework import exceptions as drf_exceptions, status
 from rest_framework.response import Response
+from rest_framework.reverse import reverse
 from rest_framework.views import exception_handler as drf_exception_handler
 from zds_client import ClientError
 
@@ -106,6 +111,27 @@ class ViewConfigView(TemplateView):
         return context
 
 
+class SchemaViewRedoc(SpectacularRedocView):
+    def _get_schema_url(self, request) -> str:
+        schema_url = self.url or get_relative_url(
+            reverse(self.url_name, request=request)
+        )
+        return f"{schema_url}openapi.yaml"
+
+
+class SchemaViewAPI(SpectacularYAMLAPIView):
+    def _get_schema_response(self, request):
+        filename = "openapi.yaml"
+
+        with open(Path(settings.BASE_DIR) / "src" / filename, "r") as file:
+            schema = yaml.safe_load(file)
+
+        return Response(
+            data=schema,
+            headers={"Content-Disposition": f'inline; filename="{filename}"'},
+        )
+
+
 def _test_sites_config(request: HttpRequest) -> list:
     if not apps.is_installed("django.contrib.sites"):
         return []
